/**
 * Copyright (C) 2010 MediaShelf <http://www.yourmediashelf.com/>
 *
 * This file is part of fedora-client.
 *
 * fedora-client is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * fedora-client is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with fedora-client.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.yourmediashelf.fedora.client.messaging;

/**
 * Implementations should override toString() to provide a serialization of the
 * message.
 *
 * @author Edwin Shin (copied from org.fcrepo.server.messaging.FedoraMessage) 
 */

public interface FedoraMessage {

    /**
     * Version of the Fedora server that produced the message
     * (version.major + version.minor), e.g. 3.0b2. Messages generated by
     * clients should return the version of the Fedora server the message
     * is intended for.
     *
     * @return Fedora server version
     */
    public String getServerVersion();

    /**
     * An identifier for the serialization format of the message.
     * @return the identifier for the message format serialization 
     * (e.g. info:fedora/fedora-system:ATOM-APIM-1.0)
     */
    public String getFormat();
}